# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Data-OptList
Version:	0.114
Release:	1.%{__distinit}%{__distvers}
Summary:	Parse and validate simple name/value option pairs
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Data-OptList
Source0:	https://cpan.metacpan.org/modules/by-module/Data/Data-OptList-%{version}.tar.gz
Patch0:		Data-OptList-0.114-old-EU::MM.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(:VERSION) >= 5.12
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.31
# Module Runtime
BuildRequires:	perl(List::Util)
BuildRequires:	perl(Params::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(Sub::Install) >= 0.921
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::More) >= 0.88
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Prereqs)
# Extra Tests
BuildRequires:	perl(Encode)
BuildRequires:	perl(Test::Pod) >= 1.41
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
# Old provides generator does not support the syntax used in this module
%if 0%{?fedora} < 21 && 0%{?rhel} < 8
Provides:	perl(Data::OptList) = %{version}
%endif


%description
Hashes are great for storing named data, but if you want more than one entry
for a name, you have to use a list of pairs. Even then, this is really boring
to write:

$values = [
    foo => undef,
    bar => undef,
    baz => undef,
    xyz => { ... },
];

With Data::OptList, you can do this instead:

$values = Data::OptList::mkopt([
    qw(foo bar baz),
    xyz => { ... },
]);

This works by assuming that any defined scalar is a name and any reference
following a name is its value.

%prep
%setup -q -n Data-OptList-%{version}

# Avoid the need for ExtUtils::MakeMaker ≥ 6.78
%patch -P 0

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Data/
%{_mandir}/man3/Data::OptList.3*

%changelog
* Sun May  7 2023 Paul Howarth <paul@city-fan.org> - 0.114-1
- Update to 0.114
  - Data::OptList now requires perl v5.12.0
  - Tests no longer add "-T" to shebang, so do not invoke taint mode
- Avoid use of deprecated patch syntax

* Sun Jan  1 2023 Paul Howarth <paul@city-fan.org> - 0.113-1
- Update to 0.113
  - Update author contact info
- Use SPDX-format license tag

* Mon Jun 28 2021 Paul Howarth <paul@city-fan.org> - 0.112-1
- Update to 0.112
  - Update author contact info
  - Add perl version support to docs
  - Replace a "goto" deep in the guts with a sub call, for speed

* Sat Jun  1 2019 Paul Howarth <paul@city-fan.org> - 0.110-10
- Modernize spec
  - Switch upstream from search.cpan.org to metacpan.org
  - BR: perl-generators unconditionally
  - BR: perl-interpreter rather than perl
  - Don't explicitly clean buildroot in %%install section
  - Drop explicit %%clean section
  - Drop support for building with Test::More < 0.88
  - Drop legacy BuildRoot: and Group: tags

* Mon Aug 15 2016 Paul Howarth <paul@city-fan.org> - 0.110-2
- BR: perl-generators where available

* Fri Mar 25 2016 Paul Howarth <paul@city-fan.org> - 0.110-1
- Update to 0.110
  - Major optimization to mkopt
- Classify buildreqs by usage
- Simplify find expression using -delete
- Update patches as needed

* Tue Sep  2 2014 Paul Howarth <paul@city-fan.org> - 0.109-3
- Drop support for old distributions prior to FC-5:
  - Drop %%defattr, redundant since rpm 4.4
  - Drop support for building with ExtUtils::MakeMaker < 6.30
- Use %%license where possible

* Fri Dec 13 2013 Paul Howarth <paul@city-fan.org> - 0.109-1
- Update to 0.109
  - Update bugtracker and repo links
- Update patches as needed

* Thu Jul 18 2013 Paul Howarth <paul@city-fan.org> - 0.108-2
- Perl 5.18 rebuild

* Sat Jul  6 2013 Paul Howarth <paul@city-fan.org> - 0.108-1
- Update to 0.108
  - Repackage, new bug tracker
- Explicitly run the extra tests
- Update patches
- Add new patch to support build with Test::More < 0.82 (note)

* Tue Jul  3 2012 Paul Howarth <paul@city-fan.org> - 0.107-6
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Fri Jan 20 2012 Paul Howarth <paul@city-fan.org> - 0.107-3
- Drop redundant buildreq perl(Test::Pod::Coverage)
- BR: perl(ExtUtils::MakeMaker), perl(List::Util) and perl(Test::More)

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> - 0.107-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri May  6 2011 Paul Howarth <paul@city-fan.org> - 0.107-1
- Update to 0.107
  - mkopt now prefers named parameters; docs updated
  - Added the name_test parameter to mkopt
- Nobody else likes macros for commands

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.106-3
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 0.106-2
- Fix dist tag for RHEL-6 Beta

* Mon Feb 15 2010 Paul Howarth <paul@city-fan.org> - 0.106-1
- Update to 0.106 (correct version style mismatch for Sub::Install)
- Bump dependency on Sub::Install to 0.921
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Fri Jan 15 2010 Paul Howarth <paul@city-fan.org> - 0.105-1
- Update to 0.105 (fix a typo in documentation)

* Wed Sep  9 2009 Paul Howarth <paul@city-fan.org> - 0.104-2
- Define RPM macros in global scope

* Thu Jan 22 2009 Paul Howarth <paul@city-fan.org> - 0.104-1
- Update to 0.104

* Mon Sep  1 2008 Paul Howarth <paul@city-fan.org> - 0.103-3
- Import from Fedora

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.103-2
- Rebuild for perl 5.10 (again)

* Thu Jan 24 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.103-1
- Rebuild for new perl
- Bump to 0.103
- Fix license tag

* Thu Sep 07 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.101-2
- Bump

* Sat Sep 02 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.101-1
- Specfile autogenerated by cpanspec 1.69.1
